/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"angl"
    "e\",\"range_mean\",\"amplitude_mean\"],\"type\":\"object\",\"title\":\"Angular "
    "Notch Filter\",\"description\":\"Angular notch filter parameters for "
    "window glass echoes\",\"properties\":{\"range_mean\":{\"type\":\"array\",\"items"
    "\":{\"type\":\"number\"},\"description\":\"Mean range [m]\"},\"amplitude_mean\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Mean amplitude"
    " [dB]\"},\"angle\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description"
    "\":\"Angle [deg]\"}}}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.12"
    "0913,2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913],\""
    "angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"temp"
    "erature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_velocit"
    "y\",\"attenuation\",\"wavelength\"],\"type\":\"object\",\"title\":\"Atmospheric "
    "Parameters\",\"description\":\"Atmospheric parameters\",\"properties\":{\"pres"
    "sure\":{\"type\":\"number\",\"description\":\"Pressure along measurment path "
    "[mbar]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) "
    "[m]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level [mbar]\"}}}"
    ,
    /* example: */
    "{\"pressure\":970,\"wavelength\":1550,\"rel_humidity\":63,\"attenuation\":0.02"
    "8125,\"temperature\":7,\"group_velocity\":299711000.0,\"amsl\":0,\"pressure_s"
    "l\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"beam"
    "_exit_diameter\",\"beam_divergence\"],\"type\":\"object\",\"title\":\"Beam "
    "Geometry\",\"description\":\"Laser beam geometry details\",\"properties\":{\"b"
    "eam_exit_diameter\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":fal"
    "se,\"description\":\"Beam width at exit aperture [m]\"},\"beam_divergence\":"
    "{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\":\"B"
    "eam divergence in far field [rad]\"}}}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Li"
    "st of control object type "
    "definitions\",\"type\":\"object\",\"title\":\"Control Object Catalog\",\"require"
    "d\":[\"types\"],\"definitions\":{\"sphere\":{\"type\":\"object\",\"allOf\":[{\"$ref\""
    ":\"#/definitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"diamete"
    "r\"],\"description\":\"sphere specific properties\",\"properties\":{\"shape\":{"
    "\"type\":\"string\",\"enum\":[\"sphere\"],\"description\":\"shape identifier\"},\"d"
    "iameter\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descrip"
    "tion\":\"diameter in meters\"}}}],\"description\":\"sphere\"},\"rectangle\":{\"t"
    "ype\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object"
    "\",\"required\":[\"shape\",\"length\",\"width\"],\"description\":\"rectangle "
    "specific properties\",\"properties\":{\"length\":{\"minimum\":0,\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"description\":\"length in meters\"},\"width\":{"
    "\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"wid"
    "th in meters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]}}}],\"desc"
    "ription\":\"rectangle\"},\"circular_disk\":{\"type\":\"object\",\"allOf\":[{\"$ref"
    "\":\"#/definitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"diamet"
    "er\"],\"description\":\"circular disk specific properties\",\"properties\":{\""
    "shape\":{\"type\":\"string\",\"enum\":[\"circular_disk\"],\"description\":\"shape "
    "identifier\"},\"diameter\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum"
    "\":true,\"description\":\"diameter in "
    "meters\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in meters, "
    "e.g. reflector constant (optional)\"}}}],\"description\":\"circular disk\"}"
    ",\"common\":{\"type\":\"object\",\"required\":[\"name\",\"shape\"],\"description\":\""
    "common object properties\",\"properties\":{\"name\":{\"type\":\"string\",\"descr"
    "iption\":\"unique type identifier\",\"minLength\":3},\"shape\":{\"type\":\"strin"
    "g\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\"circular_disk\",\"cy"
    "linder\",\"sphere\",\"round_corner_cube_prism\"],\"description\":\"shape ident"
    "ifier\"},\"surface_type\":{\"type\":\"string\",\"enum\":[\"retro_reflective_foil"
    "\",\"diffuse\"],\"description\":\"surface material "
    "type\"},\"description\":{\"type\":\"string\",\"description\":\"string describing"
    " the object\"}}},\"round_corner_cube_prism\":{\"type\":\"object\",\"allOf\":[{\""
    "$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"di"
    "ameter\"],\"description\":\"round corner cube prism specific properties\",\""
    "properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"round_corner_cube_prism"
    "\"],\"description\":\"shape identifier\"},\"diameter\":{\"minimum\":0,\"type\":\"n"
    "umber\",\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in meters, "
    "e.g. reflector constant (optional)\"}}}],\"description\":\"round corner "
    "cube prism\"},\"cylinder\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitio"
    "ns/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"diameter\",\"height\"],"
    "\"description\":\"cylinder specific properties\",\"properties\":{\"height\":{\""
    "minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"heig"
    "ht in meters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"cylinder\"],\"descripti"
    "on\":\"shape identifier\"},\"diameter\":{\"minimum\":0,\"type\":\"number\",\"exclu"
    "siveMinimum\":true,\"description\":\"diameter in meters\"}}}],\"description\""
    ":\"cylinder\"},\"checkerboard2x2\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/de"
    "finitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"square_length"
    "\"],\"description\":\"checkerboard specific properties\",\"properties\":{\"sha"
    "pe\":{\"type\":\"string\",\"enum\":[\"checkerboard2x2\"],\"description\":\"shape i"
    "dentifier\"},\"square_length\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMin"
    "imum\":true,\"description\":\"length of a square of the checkerboard in "
    "meters\"}}}],\"description\":\"checkerboard 2 by 2\"},\"chevron\":{\"type\":\"ob"
    "ject\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"requi"
    "red\":[\"shape\",\"outside_edge_length\",\"thickness\"],\"description\":\"chevro"
    "n specific properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":["
    "\"chevron\"],\"description\":\"shape identifier\"},\"thickness\":{\"minimum\":0,"
    "\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"thickness in me"
    "ters\"},\"outside_edge_length\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMi"
    "nimum\":true,\"description\":\"length of the two outer edges in meters\"}}}"
    "],\"description\":\"chevron\"}},\"properties\":{\"types\":{\"type\":\"array\",\"uni"
    "queItems\":true,\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definition"
    "s/rectangle\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/defi"
    "nitions/chevron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/de"
    "finitions/cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/defini"
    "tions/round_corner_cube_prism\"}]}}}}"
    ,
    /* example: */
    "{\"types\":[{\"length\":0.6,\"width\":0.3,\"name\":\"Rectangle "
    "60x30\",\"shape\":\"rectangle\",\"description\":\"Rectangle (60cm x "
    "30cm)\"},{\"length\":0.8,\"width\":0.4,\"name\":\"Rectangle "
    "80x40\",\"shape\":\"rectangle\",\"description\":\"Rectangle (80cm x "
    "40cm)\"},{\"name\":\"Checkerboard2x2 30\",\"shape\":\"checkerboard2x2\",\"square"
    "_length\":0.3,\"description\":\"Checkerboard (square length: "
    "30cm)\"},{\"name\":\"Checkerboard2x2 50\",\"shape\":\"checkerboard2x2\",\"square"
    "_length\":0.5,\"description\":\"Checkerboard (square length: "
    "50cm)\"},{\"name\":\"Chevron "
    "24''/4''\",\"shape\":\"chevron\",\"thickness\":0.1016,\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"outside_edge_length\":0.6096},{\"surface_type\":\"diffus"
    "e\",\"name\":\"Circular Disk "
    "50\",\"shape\":\"circular_disk\",\"diameter\":0.5,\"description\":\" Circular "
    "Disk (diameter: 50cm)\"},{\"name\":\"RIEGL flat reflector 50 mm\",\"shape\":\""
    "circular_disk\",\"surface_type\":\"retro_reflective_foil\",\"offset\":0.0,\"di"
    "ameter\":0.05,\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL flat reflector 100 mm\",\"shape\":"
    "\"circular_disk\",\"surface_type\":\"retro_reflective_foil\",\"offset\":0.0,\"d"
    "iameter\":0.1,\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL flat reflector 150 mm\",\"shape\":"
    "\"circular_disk\",\"surface_type\":\"retro_reflective_foil\",\"offset\":0.0,\"d"
    "iameter\":0.15,\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL cylindrical reflector 50 mm\",\"s"
    "hape\":\"cylinder\",\"height\":0.05,\"surface_type\":\"retro_reflective_foil\","
    "\"diameter\":0.05,\"description\":\"cylindrical reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL cylindrical reflector 100 mm\",\""
    "shape\":\"cylinder\",\"height\":0.1,\"surface_type\":\"retro_reflective_foil\","
    "\"diameter\":0.1,\"description\":\"cylindrical reflector from "
    "retro-reflective foil\"},{\"name\":\"Sphere 200 "
    "mm\",\"shape\":\"sphere\",\"diameter\":0.2,\"description\":\"Sphere (diameter: "
    "200 mm)\"},{\"name\":\"Corner Cube Prism 50 mm\",\"shape\":\"round_corner_cube"
    "_prism\",\"diameter\":0.05,\"description\":\"round corner cube "
    "prism\",\"offset\":0.0}],\"comments\":[\"This file contains a list of "
    "control object types (aka. 'catalog').\",\"Each type is described by an "
    "object,\",\"which must contain at least the following parameters:\",\"  - "
    "name: unique identifier of the type\",\"  - shape: one of the following "
    "supported shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\""
    "      - chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - "
    "sphere\",\"      - round_corner_cube_prism\",\"Depending on 'shape', the "
    "following parameters must/may be specified:\",\"  - rectangle:\",\"      -"
    " length: length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Control Object Reference file\",\"description\":\"Details about "
    "the control object reference file\",\"properties\":{\"reference_file\":{\"ty"
    "pe\":\"object\",\"required\":[\"file_uuid\",\"file_path\"],\"description\":\"Refer"
    "ence to a control object "
    "file\",\"properties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path "
    "of the control object file relative to referring "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\"}}}}}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude\",\"detection_probability\"],\"type\":\"object\",\"title\":\"Detection "
    "Probability\",\"description\":\"Detection probability as a function of amp"
    "litude\",\"properties\":{\"amplitude\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"},\"description\":\"Amplitude [dB]\"},\"detection_probability\":{\"type\":"
    "\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Detection probability"
    " [0..1]\"}}}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"devi"
    "ce_type\",\"serial_number\"],\"type\":\"object\",\"title\":\"Device "
    "Information\",\"description\":\"Details about the device used to acquire "
    "the point cloud\",\"properties\":{\"channel_text\":{\"type\":\"string\",\"descri"
    "ption\":\"Optional channel description (e.g. 'Green Channel' for "
    "multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build variant\"},\"channel_number\":{\"minimum\":0,\"type\":\"integer\",\"exclus"
    "iveMinimum\":false,\"description\":\"Laser channel number (not defined or "
    "0: single channel "
    "device)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner systems)\"}}}"
    ,
    /* example: */
    "{\"channel_text\":\"\",\"serial_number\":\"S2221234\",\"device_build\":\"\",\"chann"
    "el_number\":0,\"device_type\":\"VZ-400i\",\"device_name\":\"Scanner 1\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"prim"
    "ary\"],\"type\":\"object\",\"title\":\"Device Geometry\",\"description\":\"Scanner"
    " device geometry "
    "details\",\"properties\":{\"amu\":{\"type\":\"object\",\"description\":\"Angle "
    "Measurement Unit\",\"properties\":{\"lineCC\":{\"minimum\":0,\"type\":\"number\","
    "\"exclusiveMinimum\":false,\"description\":\"Line Circle Count (number of "
    "LSBs per full rotation about line axis)\"},\"frameCC\":{\"minimum\":0,\"type"
    "\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Frame Circle Count "
    "(number of LSBs per full rotation about frame axis)\"}}},\"secondary\":{\""
    "type\":\"object\",\"required\":[\"ID\",\"content\"],\"description\":\"Additional "
    "device geometry structure (optional)\",\"properties\":{\"content\":{\"type\":"
    "\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Internal calibration "
    "values\"},\"ID\":{\"maxItems\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},"
    "\"description\":\"Structure identifier\",\"minItems\":2}}},\"primary\":{\"type\""
    ":\"object\",\"required\":[\"ID\",\"content\"],\"description\":\"Primary device "
    "geometry structure (mandatory)\",\"properties\":{\"content\":{\"type\":\"array"
    "\",\"items\":{\"type\":\"number\"},\"description\":\"Internal calibration values"
    "\"},\"ID\":{\"maxItems\":2,\"type\":\"array\",\"items\":{\"type\":\"integer\"},\"descr"
    "iption\":\"Structure identifier\",\"minItems\":2}}}}}"
    ,
    /* example: */
    "{\"amu\":{\"lineCC\":124000,\"frameCC\":124000},\"secondary\":{\"content\":[0],\""
    "ID\":[91,0]},\"primary\":{\"content\":[0],\"ID\":[4,0]}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"prim"
    "ary\"],\"type\":\"object\",\"title\":\"Device Geometry Passive "
    "Channel\",\"description\":\"Scanner passive channel device geometry detail"
    "s\",\"properties\":{\"primary\":{\"type\":\"object\",\"required\":[\"ID\",\"content\""
    "],\"description\":\"Primary device geometry structure (mandatory)\",\"prope"
    "rties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descripti"
    "on\":\"Internal calibration values\"},\"ID\":{\"maxItems\":2,\"type\":\"array\",\""
    "items\":{\"type\":\"integer\"},\"description\":\"Structure "
    "identifier\",\"minItems\":2}}}}}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Device Output Limits\",\"description\":\"Limits of the measured "
    "values output by the device. The limits depend on the device type, "
    "measurement program and/or scan pattern.\",\"properties\":{\"reflectance_m"
    "aximum\":{\"type\":\"number\",\"description\":\"Maximum possible reflectance "
    "in dB.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible range in meters.\"},\"background_radiation_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum possible background radiation.\"},\"amplitu"
    "de_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible amplitude"
    " in "
    "dB.\"},\"reflectance_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible reflectance in "
    "dB.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape "
    "deviation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"mta_zone_count_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum number of MTA zones.\"},\"background_radiat"
    "ion_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible "
    "background radiation.\"}}}"
    ,
    /* example: */
    "{\"reflectance_maximum\":100.0,\"mta_zone_count_maximum\":7,\"deviation_max"
    "imum\":32767,\"range_minimum\":2.9,\"range_maximum\":10000.0,\"deviation_min"
    "imum\":-1,\"amplitude_maximum\":100.0,\"background_radiation_minimum\":0,\"b"
    "ackground_radiation_maximum\":0,\"reflectance_minimum\":-100.0,\"amplitude"
    "_minimum\":0.0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"array\",\"t"
    "itle\":\"Devices Information\",\"items\":{\"type\":\"object\",\"required\":[\"devi"
    "ce_type\",\"serial_number\"],\"properties\":{\"channel_text\":{\"type\":\"string"
    "\",\"description\":\"Optional channel description (e.g. 'Green Channel' "
    "for multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device "
    "build variant\"},\"channel_number\":{\"minimum\":0,\"type\":\"integer\",\"exclus"
    "iveMinimum\":false,\"description\":\"Laser channel number (not defined or "
    "0: single channel "
    "device)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly signed.\"}}},\"description\":\"Details about the devices used to"
    " acquire the point cloud (e.g. when merging point clouds of different "
    "devices)\"}"
    ,
    /* example: */
    "[{\"channel_text\":\"\",\"serial_number\":\"S2221234\",\"device_build\":\"\",\"chan"
    "nel_number\":0,\"device_type\":\"VZ-400i\",\"device_name\":\"Scanner 1\",\"signe"
    "d\":false},{\"channel_text\":\"\",\"serial_number\":\"S2222680\",\"device_build\""
    ":\"\",\"channel_number\":1,\"device_type\":\"VQ-1560i-DW\",\"device_name\":\"Scan"
    "ner 2\",\"signed\":true},{\"channel_text\":\"\",\"serial_number\":\"S2222680\",\"d"
    "evice_build\":\"\",\"channel_number\":2,\"device_type\":\"VQ-1560i-DW\",\"device"
    "_name\":\"Scanner 3\",\"signed\":true}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Dyntrig\""
    ",\"description\":\"Dyntrig\",\"properties\":{\"tab\":{\"maxItems\":128,\"type\":\"a"
    "rray\",\"items\":{\"type\":\"object\",\"required\":[\"thra1\",\"del1\",\"dec1\",\"thra"
    "2\",\"del2\",\"dec2\"],\"description\":\"...\",\"properties\":{\"thra2\":{\"type\":\"n"
    "umber\",\"description\":\"Pre-trigger threshold in units of "
    "dB\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of "
    "constant post-trigger threshold elevation in units of "
    "m\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of dB/m\"}}},\"description\":\"...\",\"minItem"
    "s\":1},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of dB, "
    "for calculation of line: line number N=(amplitude-offset)/scale\"},\"pos"
    "t\":{\"type\":\"object\",\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig post "
    "values\",\"properties\":{\"a\":{\"maxItems\":2080,\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"...\",\"minItems\":1},\"nc\":{\"minimum\":0,\"typ"
    "e\":\"integer\",\"description\":\"Number of entries\",\"maximum\":255}}},\"pre\":"
    "{\"type\":\"object\",\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig pre valu"
    "es\",\"properties\":{\"a\":{\"maxItems\":2080,\"type\":\"array\",\"items\":{\"type\":"
    "\"number\"},\"description\":\"...\",\"minItems\":1},\"nc\":{\"minimum\":0,\"type\":\""
    "integer\",\"description\":\"Number of entries\",\"maximum\":255}}},\"offset\":{"
    "\"type\":\"number\",\"description\":\"Offset in units of dB, for calculation "
    "of line\"}}}"
    ,
    /* example: */
    "{\"tab\":[{\"thra2\":0.0,\"del2\":0.0,\"thra1\":0.0,\"del1\":0.0,\"dec2\":0.0,\"dec"
    "1\":0.0}],\"scale\":1.0,\"post\":{\"a\":[78,86,126,134,31],\"nc\":128},\"pre\":{\""
    "a\":[78,86,126,134,31],\"nc\":128},\"offset\":0.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"echo"
    "_file\"],\"type\":\"object\",\"title\":\"Echo "
    "Information\",\"description\":\"Details about echo files\",\"properties\":{\"e"
    "cho_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"properties\":"
    "{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally Unique"
    " Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading dot\"}}}}}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails for exponential decomposition of full waveform "
    "data\",\"type\":\"object\",\"title\":\"Exponential Decomposition\",\"additionalP"
    "roperties\":false,\"definitions\":{\"channel\":{\"type\":\"object\",\"required\":"
    "[\"delay\",\"scale\",\"parameter\"],\"properties\":{\"scale\":{\"type\":\"number\",\""
    "description\":\"amplitude calibration\"},\"a_lin\":{\"description\":\"relative"
    " linear amplitude range [0..1]\",\"minimum\":0,\"type\":\"number\",\"exclusive"
    "Minimum\":false,\"maximum\":1,\"exclusiveMaximum\":false},\"parameter\":{\"typ"
    "e\":\"object\",\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],\"description\":\"parame"
    "ters of the syswave exponential sum\",\"properties\":{\"omega\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\"},\"description\":\"angular frequency in Hz\""
    "},\"B\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"imagina"
    "ry part of amplitude factor in units of full-scale\"},\"A\":{\"type\":\"arra"
    "y\",\"items\":{\"type\":\"number\"},\"description\":\"real part of amplitude "
    "factor in units of full-scale\"},\"gamma\":{\"type\":\"array\",\"items\":{\"type"
    "\":\"number\"},\"description\":\"decay in "
    "1/second\"}}},\"delay\":{\"type\":\"number\",\"description\":\"delay calibration"
    " in seconds\"}}}},\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definition"
    "s/channel\",\"description\":\"one field per channel, field name is channel"
    " index\"}}}"
    ,
    /* example: */
    "{\"1\":{\"scale\":1.0,\"a_lin\":0.9,\"parameter\":{\"omega\":[352020896.0,364792"
    "7552.0,-1977987072.0],\"B\":[-3.9,0.0,-0.3],\"A\":[0.9,0.3,-1.3],\"gamma\":["
    "-1094726528.0,-769562752.0,-848000064.0]},\"delay\":3.5e-09},\"0\":{\"scale"
    "\":1.0,\"a_lin\":0.27,\"parameter\":{\"omega\":[352020896.0,3647927552.0,-197"
    "7987072.0],\"B\":[-3.9813032150268555,0.08622030913829803,-0.31528609991"
    "07361],\"A\":[0.9772450923919678,0.3354335129261017,-1.312678575515747],"
    "\"gamma\":[-1094726528.0,-769562752.0,-848000064.0]},\"delay\":3.783458418"
    "887631e-09}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"range_"
    "offset_sec_low_power\",\"range_offset_sec_high_power\"],\"type\":\"object\",\""
    "title\":\"Gaussian "
    "Decomposition\",\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"properties\":{\"range_off"
    "set_sec_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplit"
    "ude_lsb_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitu"
    "de_lsb_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitu"
    "de_db\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_offset_sec_lo"
    "w_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}}}}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_lsb_low_power\":[],\"amplit"
    "ude_lsb_high_power\":[],\"amplitude_db\":[],\"range_offset_sec_low_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Geo Tag\",\"description\":\"Point cloud georeferencing information"
    "\",\"properties\":{\"pose\":{\"maxItems\":4,\"type\":\"array\",\"items\":{\"maxItems"
    "\":4,\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\":\"columns\"},\""
    "description\":\"rows\",\"minItems\":4},\"description\":\"Coordinate "
    "Transformation Matrix to transform from File Coordinate System to "
    "Global Coordinate Reference System. 4x4 matrix stored as two "
    "dimensional array, row major "
    "order.\",\"minItems\":4},\"crs\":{\"type\":\"object\",\"description\":\"Global "
    "Coordinate Reference System. Please note that only 3D Cartesian "
    "Coordinate Systems are allowed.\",\"properties\":{\"wkt\":{\"type\":\"string\","
    "\"description\":\"\\\"Well-Known Text\\\" string, OGC WKT dialect (see http:/"
    "/www.opengeospatial.org/standards/wkt-crs)\"},\"name\":{\"type\":\"string\",\""
    "description\":\"Coordinate reference system "
    "name\"},\"epsg\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"EPSG "
    "code\"}}}}}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS"
    "84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\"
    "\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000"
    "000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.0000000000000"
    "0000000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAS"
    "T],AXIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 "
    "Geocentric\",\"epsg\":4978}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"number\",\""
    "exclusiveMinimum\":true,\"minimum\":0,\"description\":\"Geometric scale "
    "factor applied to point coordinates\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Georeferencing Parameters\",\"description\":\"Parameters used for "
    "georeferencing of the point cloud\",\"properties\":{\"socs_to_rocs_matrix\""
    ":{\"maxItems\":4,\"type\":\"array\",\"items\":{\"maxItems\":4,\"type\":\"array\",\"it"
    "ems\":{\"type\":\"number\",\"description\":\"columns\"},\"description\":\"rows\",\"m"
    "inItems\":4},\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Record Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"minItems\":4},\"socs_to_body_matrix\":{\"maxItems\":4,\"type\":\"array\",\"item"
    "s\":{\"maxItems\":4,\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\""
    ":\"columns\"},\"description\":\"rows\",\"minItems\":4},\"description\":\"Coordina"
    "te Transformation Matrix to transform from Scanner's Own Coordinate "
    "System to Body Coordinate System. 4x4 matrix stored as two dimensional"
    " array, row major order.\",\"minItems\":4},\"body_coordinate_system_type\":"
    "{\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"],\"description\":\"BODY coordinate "
    "frame (NED: North-East-Down, ENU: East-North-Up), default: "
    "NED\"},\"trajectory_offsets\":{\"type\":\"object\",\"description\":\"Correction "
    "offsets applied to the trajectory data\",\"properties\":{\"offset_north\":{"
    "\"type\":\"number\",\"description\":\"[m]\"},\"offset_yaw\":{\"type\":\"number\",\"de"
    "scription\":\"[deg]\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\""
    "},\"offset_height\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_east\":"
    "{\"type\":\"number\",\"description\":\"[m]\"},\"version\":{\"type\":\"integer\",\"des"
    "cription\":\"Meaning of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_roll\":{\"type\":\"number\",\"description\":\"[deg"
    "]\"},\"offset_pitch\":{\"type\":\"number\",\"description\":\"[deg]\"}}},\"trajecto"
    "ry_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"description\":"
    "\"Trajectory data used for georeferencing of the point cloud\",\"properti"
    "es\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}}}}}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "body_coordinate_system_type\":\"NED\",\"trajectory_offsets\":{\"offset_north"
    "\":0.07,\"offset_yaw\":-0.45,\"offset_time\":18.007,\"offset_height\":-0.2,\"o"
    "ffset_east\":0.15,\"version\":0,\"offset_roll\":0.03,\"offset_pitch\":0.01},\""
    "trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\""
    "file_extension\":\"pofx\"}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Item Names\",\"additionalProperties\":false,\"description\":\"Map of"
    " item names\",\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"descr"
    "iption\":\"One field per item, field name is item id, field value is "
    "item name\"}}}"
    ,
    /* example: */
    "{\"-1\":\"Name of item with id -1\",\"47\":\"Name of item with id "
    "47\",\"1\":\"Name of item with id 1\",\"2\":\"Name of item with id 2\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Software License "
    "Keys\",\"additionalProperties\":false,\"description\":\"License keys for "
    "software features\",\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"items\""
    ":{\"type\":\"string\",\"description\":\"License key (example: '46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73')\"},\"description\":\"Each field of the "
    "object represents a feature and holds a list of license keys, where "
    "the field name is the feature name.\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA "
    "- 8D2ED557\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"MTA Settings\",\"description\":\"Parameters for MTA processing\",\"p"
    "roperties\":{\"zone_count\":{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\""
    "description\":\"Maximum number of MTA zones.\"},\"modulation_depth\":{\"mini"
    "mum\":0,\"type\":\"number\",\"description\":\"Depth of pulse position "
    "modulation in meter.\"},\"zone_width\":{\"minimum\":0,\"type\":\"number\",\"desc"
    "ription\":\"Width of a MTA zone in meter.\"}}}"
    ,
    /* example: */
    "{\"zone_count\":23,\"modulation_depth\":9.368514,\"zone_width\":149.896225}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"delt"
    "a\",\"content\"],\"type\":\"object\",\"title\":\"Near Range Correction "
    "Table\",\"description\":\"Lookup table for range correction based on raw "
    "range\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"maxItems\":2000,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\""
    ":\"Correction value [m] to be added to the raw range\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude\",\"range_sigma\",\"amplitude_sigma\"],\"type\":\"object\",\"title\":\"Noise"
    " Estimates\",\"description\":\"Standard deviation for range and amplitude "
    "as a function of amplitude\",\"properties\":{\"range_sigma\":{\"type\":\"array"
    "\",\"items\":{\"type\":\"number\"},\"description\":\"Sigma range [m]\"},\"amplitud"
    "e\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Amplitude "
    "[dB]\"},\"amplitude_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"de"
    "scription\":\"Sigma amplitude [dB]\"}}}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0"
    "],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0."
    "432,0.39,0.354]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"rang"
    "e_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"type\":\"object\",\"title"
    "\":\"Notch Filter\",\"description\":\"Notch filter parameters for window "
    "glass echoes\",\"properties\":{\"amplitude_maximum\":{\"minimum\":0,\"type\":\"n"
    "umber\",\"description\":\"Maximum amplitude "
    "[dB]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range "
    "[m]\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"}}}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about the pixels contained in the "
    "file\",\"type\":\"object\",\"title\":\"Pixel Information\",\"required\":[\"size\"],"
    "\"definitions\":{\"pixel_size\":{\"maxItems\":2,\"type\":\"array\",\"items\":{\"min"
    "imum\":0,\"type\":\"number\",\"description\":\"Length of pixel edge "
    "[m].\"},\"description\":\"Size of pixels.\",\"minItems\":2}},\"properties\":{\"s"
    "ize\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of pixels "
    "in file coordinate system.\"},\"size_llcs\":{\"$ref\":\"#/definitions/pixel_"
    "size\",\"description\":\"Size of pixels in a locally levelled cartesian "
    "coordinate system (xy). This is only used for pixels based on a map "
    "projection.\"}}}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about the plane patch matching "
    "process\",\"type\":\"object\",\"title\":\"Plane Patch Matching\",\"required\":[\"p"
    "lane_patch_file_one\",\"plane_patch_file_two\"],\"definitions\":{\"file_refe"
    "rence\":{\"type\":\"object\",\"required\":[\"file_uuid\",\"file_path\"],\"descript"
    "ion\":\"Reference to a plane patch "
    "file\",\"properties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path "
    "of the plane patch file relative to the match "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\"}}}},\"properties\":{\"plane_pat"
    "ch_file_one\":{\"$ref\":\"#/definitions/file_reference\",\"description\":\"Ref"
    "erence to the plane patch file one\"},\"plane_patch_file_two\":{\"$ref\":\"#"
    "/definitions/file_reference\",\"description\":\"Reference to the plane "
    "patch file two\"}}}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_path\":\"Record009_Line001/191025_121410_"
    "Scanner_1.ptch\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"},\"p"
    "lane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d509"
    "-a64e-49ce-8b14-ff3130fbefa9\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Plane Patch Statistics\",\"description\":\"Statistics about plane "
    "patches found by plane patch extractor\",\"properties\":{\"total_horizonta"
    "l_area\":{\"type\":\"number\",\"description\":\"sum of all plane patch areas "
    "projected to horizontal plane "
    "[m\\u00b2]\"},\"total_area\":{\"type\":\"number\",\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\"}}}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Se"
    "ttings and classes for plane slope "
    "classification\",\"type\":\"object\",\"title\":\"Plane Slope Class Info\",\"requ"
    "ired\":[\"settings\",\"classes\"],\"definitions\":{\"method-1\":{\"type\":\"object"
    "\",\"required\":[\"plane_classification_method\",\"maximum_inclination_angle"
    "_horizontal\"],\"description\":\"Classification method 1\",\"properties\":{\"m"
    "aximum_inclination_angle_horizontal\":{\"minimum\":-360.0,\"type\":\"number\""
    ",\"maximum\":360.0,\"description\":\"maximum inclination angle of "
    "horizontal plane patches [deg]\"},\"plane_classification_method\":{\"minim"
    "um\":1,\"type\":\"integer\",\"maximum\":1,\"description\":\"method ID (=1)\"}}},\""
    "method-2\":{\"type\":\"object\",\"required\":[\"plane_classification_method\",\""
    "sloping_plane_classes_minimum_angle\",\"sloping_plane_classes_maximum_an"
    "gle\"],\"description\":\"Classification method 2\",\"properties\":{\"sloping_p"
    "lane_classes_maximum_angle\":{\"minimum\":-360.0,\"type\":\"number\",\"maximum"
    "\":360.0,\"description\":\"maximum inclination angle of sloping plane "
    "patches [deg]\"},\"plane_classification_method\":{\"minimum\":2,\"type\":\"int"
    "eger\",\"maximum\":2,\"description\":\"method ID (=2)\"},\"sloping_plane_class"
    "es_minimum_angle\":{\"minimum\":-360.0,\"type\":\"number\",\"maximum\":360.0,\"d"
    "escription\":\"minimum inclination angle of sloping plane patches [deg]\""
    "}}}},\"properties\":{\"settings\":{\"type\":\"object\",\"description\":\"Classifi"
    "cation settings, details see documentation of rdbplanes\",\"oneOf\":[{\"$r"
    "ef\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method-2\"}]},\"cla"
    "sses\":{\"type\":\"object\",\"additionalProperties\":false,\"description\":\"Cla"
    "ss definition table\",\"patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\","
    "\"description\":\"one field per class, field name is class number, field "
    "value is class name\"}}}}}"
    ,
    /* example: */
    "{\"settings\":{\"sloping_plane_classes_maximum_angle\":70.0,\"plane_classif"
    "ication_method\":2,\"sloping_plane_classes_minimum_angle\":10.0},\"classes"
    "\":{\"1\":\"horizontal, pointing up\",\"10\":\"sloping, pointing down and "
    "east\",\"6\":\"vertical, pointing east\",\"7\":\"vertical, pointing "
    "south\",\"3\":\"sloping, pointing up and south\",\"4\":\"sloping, pointing up "
    "and north\",\"12\":\"sloping, pointing down and north\",\"11\":\"sloping, "
    "pointing down and south\",\"8\":\"vertical, pointing north\",\"2\":\"sloping, "
    "pointing up and east\",\"13\":\"sloping, pointing down and "
    "west\",\"5\":\"sloping, pointing up and west\",\"9\":\"vertical, pointing "
    "west\",\"14\":\"horizontal, pointing down\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Point Attribute "
    "Groups\",\"additionalProperties\":false,\"description\":\"Grouping and "
    "sorting of point attributes for visualization purposes\",\"patternProper"
    "ties\":{\"^.*$\":{\"type\":\"array\",\"items\":{\"type\":\"string\",\"description\":\""
    "Point attribute full name or name pattern (perl regular expression "
    "syntax)\"},\"description\":\"Each field of the object represents a point "
    "attribute group and holds a list of point attributes, where the field "
    "name is the group name.\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Time\":[\"riegl.timestamp\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Secondary Attributes\":"
    "[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Coordinates/Vectors"
    "\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl.phi\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Point Cloud Information\",\"description\":\"Details about point "
    "cloud files\",\"properties\":{\"comments\":{\"type\":\"string\",\"description\":\""
    "Comments\"},\"field_of_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\""
    "SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field "
    "of application\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"}}}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"field_of_application\":\"ALS\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"orie"
    "ntation\"],\"type\":\"object\",\"title\":\"Pose "
    "Estimation\",\"description\":\"Estimated position and orientation "
    "information as measured by GNSS, IMU or inclination sensors\",\"properti"
    "es\":{\"barometric_height_amsl\":{\"type\":\"number\",\"description\":\"Altitude"
    " determined based on the atmospheric pressure according to the "
    "standard atmosphere laws [m].\"},\"orientation\":{\"type\":\"object\",\"requir"
    "ed\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accura"
    "cy\"],\"description\":\"Orientation values and orientation accuracies, "
    "measured with IMU or inclination sensors.\",\"properties\":{\"yaw\":{\"minim"
    "um\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Yaw angle about "
    "scanner Z-axis [deg]\"},\"pitch_accuracy\":{\"minimum\":0,\"type\":\"number\",\""
    "exclusiveMinimum\":true,\"description\":\"Pitch angle accuracy [deg]\"},\"pi"
    "tch\":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Pitc"
    "h angle about scanner Y-axis [deg]\"},\"roll\":{\"minimum\":-360,\"type\":\"nu"
    "mber\",\"maximum\":360,\"description\":\"Roll angle about scanner X-axis [de"
    "g]\"},\"roll_accuracy\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":t"
    "rue,\"description\":\"Roll angle accuracy [deg]\"},\"yaw_accuracy\":{\"minimu"
    "m\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Yaw angle "
    "accuracy [deg]\"}}},\"position\":{\"type\":\"object\",\"required\":[\"coordinate"
    "_1\",\"coordinate_2\",\"coordinate_3\",\"horizontal_accuracy\",\"vertical_accu"
    "racy\",\"crs\"],\"description\":\"Position coordinates and position accuracy"
    " values as measured by GNSS in the specified Coordinate Reference "
    "System (CRS)\",\"properties\":{\"coordinate_2\":{\"type\":\"number\",\"descripti"
    "on\":\"Coordinate 2 as defined by axis 2 of the specified CRS (e.g., Y, "
    "Longitude)\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate"
    " 3 as defined by axis 3 of the specified CRS (e.g., Z, "
    "Altitude)\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate "
    "1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)\"},\"crs"
    "\":{\"type\":\"object\",\"required\":[\"epsg\"],\"description\":\"Global "
    "Coordinate Reference System\",\"properties\":{\"wkt\":{\"type\":\"string\",\"des"
    "cription\":\"\\\"Well-Known Text\\\" string, OGC WKT dialect (see http://www"
    ".opengeospatial.org/standards/wkt-crs)\"},\"epsg\":{\"minimum\":0,\"type\":\"i"
    "nteger\",\"description\":\"EPSG code\"}}},\"horizontal_accuracy\":{\"minimum\":"
    "0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Horizontal "
    "accuracy [m]\"},\"vertical_accuracy\":{\"minimum\":0,\"type\":\"number\",\"exclu"
    "siveMinimum\":true,\"description\":\"Vertical accuracy [m]\"}}}}}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"orientation\":{\"yaw\":101.8"
    "7293630292045,\"pitch_accuracy\":0.009433783936875745,\"pitch\":1.50915302"
    "4827064,\"roll\":3.14743073066123,\"roll_accuracy\":0.009433783936875745,\""
    "yaw_accuracy\":1.0094337839368757},\"position\":{\"coordinate_2\":15.645033"
    "406,\"coordinate_3\":362.7124938964844,\"coordinate_1\":48.655799473,\"crs\""
    ":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS8"
    "4\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY["
    "\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY["
    "\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\"
    "\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],A"
    "UTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"epsg\":4979},\"horizontal_accuracy\":0.810"
    "699999332428,\"vertical_accuracy\":1.3314999341964722}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails on position and orientation "
    "sensors\",\"type\":\"object\",\"title\":\"Pose Sensors\",\"required\":[\"gyroscope"
    "\",\"accelerometer\",\"magnetic_field_sensor\"],\"definitions\":{\"vector\":{\"m"
    "axItems\":3,\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\":\"Inde"
    "x 0=X, 1=Y, 2=Z component\"},\"minItems\":3}},\"properties\":{\"acceleromete"
    "r\":{\"type\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"off"
    "set\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Accelerometer de"
    "tails\",\"properties\":{\"relative_nonlinearity\":{\"$ref\":\"#/definitions/ve"
    "ctor\",\"description\":\"Relative nonlinearity, dimensionless\"},\"z_axis\":{"
    "\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z axis of "
    "sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"unit\":{\"minimum\":0,\"type\":\""
    "number\",\"exclusiveMinimum\":true,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\"},\"x_axis\":{\"$ref\":\"#/defi"
    "nitions/vector\",\"description\":\"Sensitive X axis of sensor at frame "
    "angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = "
    "0\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\"}}},\"magnetic_field_sensor\":{\"ty"
    "pe\":\"object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"f"
    "ixed\",\"relative_nonlinearity\"],\"description\":\"Magnetic Field Sensor de"
    "tails\",\"properties\":{\"relative_nonlinearity\":{\"$ref\":\"#/definitions/ve"
    "ctor\",\"description\":\"Relative nonlinearity, dimensionless\"},\"z_axis\":{"
    "\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z axis of "
    "sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"unit\":{\"minimum\":0,\"type\":\""
    "number\",\"exclusiveMinimum\":true,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in "
    "nT\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "X axis of sensor at frame angle = "
    "0\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner part\"},\"y_axis\":{\"$re"
    "f\":\"#/definitions/vector\",\"description\":\"Sensitive Y axis of sensor at"
    " frame angle = 0\"}}},\"gyroscope\":{\"type\":\"object\",\"required\":[\"unit\",\""
    "x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\""
    "description\":\"Gyroscope details\",\"properties\":{\"relative_nonlinearity\""
    ":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, "
    "dimensionless\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":"
    "\"Sensitive Z axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"unit\":{\"minimum\":0,\"type\":\""
    "number\",\"exclusiveMinimum\":true,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\"},\"x_axis\":{\"$ref\":\"#/definitions/v"
    "ector\",\"description\":\"Sensitive X axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = "
    "0\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\"}}}}}"
    ,
    /* example: */
    "{\"accelerometer\":{\"relative_nonlinearity\":[0.0,0.0,0.0],\"z_axis\":[1.63"
    "9882206916809,15166.744140625,-116.99742889404297],\"offset\":[-733.3636"
    "474609375,58.969032287597656,1060.2550048828125],\"unit\":6.666666740784"
    "422e-05,\"x_axis\":[-15008.123046875,56.956390380859375,-60.517566680908"
    "2],\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.3701171875],\""
    "origin\":[0.026900000870227814,-0.03999999910593033,-0.0895000025629997"
    "3]},\"magnetic_field_sensor\":{\"relative_nonlinearity\":[0.0,0.0,0.0],\"z_"
    "axis\":[0.00041987866279669106,7.876977906562388e-05,0.0114071043208241"
    "46],\"offset\":[-23812.052734375,5606.57666015625,2493.28125],\"unit\":91."
    "74311828613281,\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05,"
    "0.00016818844596855342],\"fixed\":[-1576.010498046875,1596.081787109375,"
    "0.0],\"y_axis\":[0.00027888521435670555,-0.011427424848079681,-5.2048297"
    "22060822e-05]},\"gyroscope\":{\"relative_nonlinearity\":[2.888176311444113"
    "e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"z_axis\":[0.5558699"
    "96547699,119.22135162353516,0.467585027217865],\"offset\":[-50.926097869"
    "87305,146.15643310546875,62.4327278137207],\"unit\":0.000145444108056835"
    "83,\"x_axis\":[-121.195556640625,0.8219714164733887,0.2313031703233719],"
    "\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.5894775390625],\"o"
    "rigin\":[0.026900000870227814,-0.03999999910593033,-0.08950000256299973"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"leng"
    "th\",\"num_mod_ampl\",\"pulse_interval\"],\"type\":\"object\",\"title\":\"Pulse "
    "Position Modulation\",\"description\":\"Laser pulse position modulation "
    "used for MTA resolution\",\"properties\":{\"length\":{\"minimum\":0,\"type\":\"i"
    "nteger\",\"maximum\":255,\"description\":\"Length of code\"},\"num_mod_ampl\":{"
    "\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"Number of "
    "different modulation amplitudes (2: binary modulation)\"},\"phase_step\":"
    "{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"Step width "
    "in phase of modulation code from line to line\"},\"code_phase_mode\":{\"mi"
    "nimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\"},\"pulse_interval\":{\"type\":\"array\",\"items\":{\"minimum\":0,\"type"
    "\":\"number\"},\"description\":\"Explicit table of the pulse position "
    "modulation used for MTA resolution. Table gives times between "
    "successive laser pulses in seconds.\"}}}"
    ,
    /* example: */
    "{\"length\":31,\"num_mod_ampl\":2,\"phase_step\":5,\"code_phase_mode\":2,\"puls"
    "e_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821"
    "875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-"
    "06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2."
    "821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.75937"
    "5e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06"
    ",2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06]}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"mini"
    "mum\",\"average\",\"maximum\",\"std_dev\"],\"type\":\"object\",\"title\":\"Range "
    "Statistics\",\"description\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"properties\":{\"minimum\":{\"type\":\"number\",\"description\":\"Minimu"
    "m value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average value\"}}}"
    ,
    /* example: */
    "{\"minimum\":0.919,\"std_dev\":24.349,\"maximum\":574.35,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Re"
    "ceiver Internals\",\"type\":\"object\",\"title\":\"Receiver Internals\",\"defini"
    "tions\":{\"fp\":{\"type\":\"object\",\"required\":[\"s\",\"w\"],\"description\":\"Fing"
    "erprint values\",\"properties\":{\"w\":{\"maxItems\":256,\"type\":\"array\",\"item"
    "s\":{\"maxItems\":5,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"minItems\":5"
    "},\"minItems\":1},\"s\":{\"maxItems\":256,\"type\":\"array\",\"items\":{\"maxItems\""
    ":4096,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"minItems\":1},\"minItems"
    "\":1}}},\"fp_table\":{\"type\":\"object\",\"properties\":{\"ch\":{\"max\":255,\"type"
    "\":\"integer\",\"min\":0,\"description\":\"channel number\"},\"nx\":{\"max\":2048,\""
    "type\":\"integer\",\"min\":1,\"description\":\"number of x entries\"},\"tv\":{\"ma"
    "xItems\":2048,\"type\":\"array\",\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/f"
    "p_table_row\"},{\"type\":\"number\"}]},\"minItems\":1},\"ny\":{\"max\":2048,\"type"
    "\":\"integer\",\"min\":1,\"description\":\"number of y entries\"},\"tc\":{\"max\":2"
    "55,\"type\":\"integer\",\"min\":0,\"description\":\"table data type "
    "code\"}},\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"desription\":\"scanner "
    "internal data\"},\"fp_table_row\":{\"maxItems\":2048,\"type\":\"array\",\"items\""
    ":{\"type\":\"number\"},\"minItems\":1}},\"properties\":{\"mw\":{\"minimum\":0,\"typ"
    "e\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Maximum weight\",\"ma"
    "ximum\":4095},\"a\":{\"maxItems\":256,\"type\":\"array\",\"items\":{\"type\":\"numbe"
    "r\"},\"description\":\"Amplitude [dB]\",\"minItems\":1},\"sr\":{\"minimum\":0,\"ty"
    "pe\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Sample rate [Hz]\"}"
    ",\"tbl\":{\"type\":\"array\",\"items\":{\"$ref\":\"#/definitions/fp_table\"},\"desc"
    "ription\":\"various internal data\",\"minItems\":1},\"nt\":{\"minimum\":0,\"type"
    "\":\"integer\",\"description\":\"Number of traces\",\"maximum\":255},\"ns\":{\"min"
    "imum\":0,\"type\":\"integer\",\"description\":\"Number of samples\",\"maximum\":4"
    "095},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' instead\"},\"t\":{\"type\":\"object\",\"addi"
    "tionalProperties\":false,\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/def"
    "initions/fp\",\"description\":\"one field per channel, field name is "
    "channel "
    "index\"}}},\"si\":{\"minimum\":0,\"type\":\"number\",\"description\":\"Start index"
    " (hw_start)\",\"maximum\":255}}}"
    ,
    /* example: */
    "{\"mw\":31,\"a\":[-1.55],\"sr\":7959997000.0,\"tbl\":[{\"ch\":0,\"nx\":5,\"tv\":[[1,"
    "2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"ny\":2,\"tc\":1}],\"nt\":128,\"ns\":400,\"t\":"
    "{\"1\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s\":[[1.23,4.56],[7."
    "89,0.12]]},\"0\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s\":[[1.23"
    ",4.56],[7.89,0.12]]}},\"si\":48}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"delt"
    "a\",\"content\"],\"type\":\"object\",\"title\":\"Reflectance Calculation "
    "Table\",\"description\":\"Lookup table for reflectance calculation based "
    "on amplitude and "
    "range\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"maxItems\":2000,\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\""
    ":\"Correction value [dB] to be added to the amplitude\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"rang"
    "es_m\",\"line_angles_deg\",\"reflectance_correction_db\"],\"type\":\"object\",\""
    "title\":\"Near-range reflectance "
    "correction\",\"description\":\"Range-dependent and scan-angle-dependent "
    "correction of reflectance reading\",\"properties\":{\"reflectance_correcti"
    "on_db\":{\"type\":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number"
    "\",\"description\":\"columns (each value corresponds to an "
    "angle)\"},\"description\":\"rows (each array corresponds to a "
    "range)\"},\"description\":\"Near range reflectance correction in dB as a "
    "function of range over angle\"},\"ranges_m\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"Range [m]\"},\"line_angles_deg\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\"},\"description\":\"Angle [deg]\"}}}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ra"
    "nges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2"
    ".5,3.0,3.5,4.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Scan Pat"
    "tern\",\"definitions\":{\"program\":{\"type\":\"object\",\"required\":[\"name\"],\"d"
    "escription\":\"Measurement "
    "program\",\"properties\":{\"name\":{\"type\":\"string\",\"description\":\"Name of "
    "measurement program\"},\"laser_prr\":{\"minimum\":0,\"type\":\"number\",\"exclus"
    "iveMinimum\":false,\"description\":\"Laser Pulse Repetition Rate "
    "[Hz]\"}}}},\"description\":\"Scan pattern description\",\"properties\":{\"segm"
    "ents\":{\"type\":\"object\",\"required\":[\"list\"],\"description\":\"Segmented "
    "Line Scan Pattern\",\"properties\":{\"list\":{\"type\":\"array\",\"items\":{\"type"
    "\":\"object\",\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line"
    " Scan Segment\",\"properties\":{\"start\":{\"minimum\":0.0,\"type\":\"number\",\"m"
    "aximum\":360.0,\"description\":\"Start angle in SOCS [deg]\"},\"increment\":{"
    "\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\"description\":\"Increment "
    "of angle in SOCS [deg]\"},\"stop\":{\"minimum\":0.0,\"type\":\"number\",\"maximu"
    "m\":720.0,\"description\":\"Stop angle in SOCS [deg]\"}}}},\"program\":{\"$ref"
    "\":\"#/definitions/program\"}}},\"line\":{\"type\":\"object\",\"required\":[\"star"
    "t\",\"stop\",\"increment\"],\"description\":\"Line Scan Pattern\",\"properties\":"
    "{\"start\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":"
    "\"Start angle in SOCS [deg]\"},\"increment\":{\"minimum\":0.0,\"type\":\"number"
    "\",\"maximum\":90.0,\"description\":\"Increment of angle in SOCS [deg]\"},\"st"
    "op\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop"
    " angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/definitions/program\"}}},\"r"
    "ectangular\":{\"type\":\"object\",\"required\":[\"phi_start\",\"phi_stop\",\"phi_i"
    "ncrement\",\"theta_start\",\"theta_stop\",\"theta_increment\"],\"description\":"
    "\"Rectangular Field Of View Scan Pattern\",\"properties\":{\"phi_increment\""
    ":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\"description\":\"Incremen"
    "t of phi angle in SOCS [deg]\"},\"theta_stop\":{\"minimum\":0.0,\"type\":\"num"
    "ber\",\"maximum\":180.0,\"description\":\"Stop theta angle in SOCS [deg]\"},\""
    "program\":{\"$ref\":\"#/definitions/program\"},\"theta_increment\":{\"minimum\""
    ":0.0,\"type\":\"number\",\"maximum\":90.0,\"description\":\"Increment of theta "
    "angle in SOCS [deg]\"},\"phi_start\":{\"minimum\":0.0,\"type\":\"number\",\"maxi"
    "mum\":360.0,\"description\":\"Start phi angle in SOCS [deg]\"},\"phi_stop\":{"
    "\"minimum\":0.0,\"type\":\"number\",\"maximum\":720.0,\"description\":\"Stop phi "
    "angle in SOCS [deg]\"},\"theta_start\":{\"minimum\":0.0,\"type\":\"number\",\"ma"
    "ximum\":180.0,\"description\":\"Start theta angle in SOCS [deg]\"}}}}}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_increment\":0.04,\"theta_stop\":130.0,\"program\":{\"na"
    "me\":\"High Speed\",\"laser_prr\":100000.0},\"theta_increment\":0.04,\"phi_sta"
    "rt\":45.0,\"phi_stop\":270.0,\"theta_start\":30.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Shot Information\",\"description\":\"Details about laser shot file"
    "s\",\"properties\":{\"shot_file\":{\"type\":\"object\",\"required\":[\"file_extens"
    "ion\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's"
    " Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}}}}}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"acti"
    "vated\",\"filters\"],\"type\":\"object\",\"title\":\"Stored "
    "filters\",\"description\":\"Point filters applied in addition to the "
    "application-defined filters\",\"properties\":{\"activated\":{\"type\":\"boolea"
    "n\",\"description\":\"Apply ('true') or ignore ('false') all filters\"},\"fi"
    "lters\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"required\":[\"activated"
    "\",\"title\",\"description\",\"filter\"],\"description\":\"Point filter "
    "definition\",\"properties\":{\"title\":{\"type\":\"string\",\"description\":\"A "
    "short filter title (e.g. for display in a selection "
    "list)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter string"
    " to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"}}},\"description\":\"List of point filters\"}}}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"title\":\"Ignore uncertain points from "
    "MTA resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with uncertain MTA "
    "zone assignment\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with an echo signal "
    "amplitude below the dynamic trigger\"},{\"title\":\"Ignore points outside "
    "outer AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are outside the"
    " outer AABB in BOCS\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are inside the "
    "inner AABB in BOCS\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"$cla"
    "ss\",\"version\",\"author\",\"timestamp\",\"system\"],\"type\":\"object\",\"title\":\""
    "System Description\",\"description\":\"Details of major system components "
    "like lidar sensors, cameras and navigation "
    "devices\",\"properties\":{\"system\":{\"type\":\"object\",\"description\":\"The "
    "actual system description, details see documentation of RIEGL System D"
    "escription\"},\"$class\":{\"type\":\"string\",\"enum\":[\"Document\"],\"descriptio"
    "n\":\"Object class "
    "name\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time of "
    "creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"version\":{\"type\":\"string\""
    ",\"description\":\"Document format "
    "version\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the author "
    "that created the document\"}}}"
    ,
    /* example: */
    "{\"system\":{\"details\":\"see documentation of RIEGL System Description\"},"
    "\"$class\":\"Document\",\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"version\":"
    "\"1.2.1\",\"author\":\"RIEGL LMS GmbH, Austria\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Co"
    "nversion of background radiation raw values to temperatures in "
    "\\u00b0C\",\"type\":\"object\",\"title\":\"Temperature Calculation Table\",\"defi"
    "nitions\":{\"conversion_table\":{\"type\":\"object\",\"required\":[\"value\",\"tem"
    "perature\"],\"properties\":{\"value\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"description\":\"LSB [1]\"},\"temperature\":{\"type\":\"array\",\"items\":{\""
    "type\":\"number\"},\"description\":\"Temperature [\\u00b0C]\"}}}},\"properties\""
    ":{\"Si\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"Convers"
    "ion table for Si channel\"},\"InGaAs_Si_Difference\":{\"$ref\":\"#/definitio"
    "ns/conversion_table\",\"description\":\"Conversion table for InGaAs - Si d"
    "ifference\"},\"InGaAs\":{\"$ref\":\"#/definitions/conversion_table\",\"descrip"
    "tion\":\"Conversion table for InGaAs channel\"}}}"
    ,
    /* example: */
    "{\"Si\":{\"value\":[0.0,64.00097659230323,128.0019531846065,192.0029297769"
    "097,256.0039063692129,320.00488296151616,384.0058595538194,448.0068361"
    "461226,512.0078127384259],\"temperature\":[546.300048828125,548.81640512"
    "12026,551.3143938500972,554.0144257850053,556.604252334815,559.2124464"
    "488079,561.8022729986177,564.4104671126105,567.0002936624203]},\"InGaAs"
    "_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.04425183874,13"
    "00.1342814416948,1400.0885036774805,1500.0427259132668,1600.1327555162"
    "209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1749.977111117893,1744.7813348796044,1681.9971312601092,1622.3"
    "944822534868]},\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.0019531846"
    "065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595"
    "538194,448.0068361461226,512.0078127384259],\"temperature\":[307.2219672"
    "2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213"
    "7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3"
    "157023200148]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"epoc"
    "h\",\"source\"],\"type\":\"object\",\"title\":\"Time Base\",\"description\":\"Base "
    "of timestamps (epoch)\",\"properties\":{\"system\":{\"type\":\"string\",\"enum\":"
    "[\"unknown\",\"UTC\",\"GPS\"],\"description\":\"Time system (time "
    "standard)\"},\"epoch\":{\"type\":\"string\",\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\"},\"source\":{\"type\":\"string\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"descrip"
    "tion\":\"Timestamp source\"}}}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"time"
    "_interval\",\"navigation_frame\"],\"type\":\"object\",\"title\":\"Trajectory "
    "Information\",\"description\":\"Details about position+orientation files\","
    "\"properties\":{\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. "
    "city/state/country\"},\"company\":{\"type\":\"string\",\"description\":\"Company"
    " name\"},\"field_of_application\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS"
    "\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field of "
    "application\"},\"project\":{\"type\":\"string\",\"description\":\"Project name\"}"
    ",\"navigation_frame\":{\"type\":\"string\",\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"d"
    "escription\":\"Navigation frame (NED: North-East-Down, ENU: "
    "East-North-Up)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation "
    "device, e.g. name/type/serial\"},\"time_interval\":{\"type\":\"object\",\"requ"
    "ired\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"description\":\"Time "
    "interval statistics\",\"properties\":{\"minimum\":{\"type\":\"number\",\"descrip"
    "tion\":\"Minimum time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time"
    " interval [s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time"
    " interval [s]\"}}},\"settings\":{\"type\":\"string\",\"description\":\"Settings "
    "used to calculate the trajectory (descriptive "
    "text)\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the file)\"}}}"
    ,
    /* example: */
    "{\"location\":\"Horn\",\"company\":\"RIEGL "
    "LMS\",\"field_of_application\":\"MLS\",\"project\":\"Campaign "
    "3\",\"navigation_frame\":\"NED\",\"device\":\"IMU Model 12/1, Serial# 12345\",\""
    "time_interval\":{\"minimum\":0.00500032,\"std_dev\":5.51e-07,\"maximum\":0.00"
    "5004883,\"average\":0.00500053},\"settings\":\"default\",\"software\":\"Navigat"
    "ion Software XYZ\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ttip"
    "_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\"ext_delay\",\"ext_su"
    "bdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"dmi_max_time\",\"dmi_"
    "dist_per_tick\",\"channel\",\"output_descr\",\"input_descr\",\"output_usage\",\""
    "input_usage\",\"out_polarity\",\"out_duration\",\"out_interval\",\"out_delay\","
    "\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in_max_duration\",\"in"
    "_max_delay\"],\"type\":\"object\",\"title\":\"TTIP "
    "Configuration\",\"description\":\"Trigger-Timestamping-Unit/IP configurati"
    "on\",\"properties\":{\"dmi_min_time\":{\"minimum\":0,\"type\":\"integer\",\"descri"
    "ption\":\"dmi, minimum time interval between trigger events [0.1 msec]\"}"
    ",\"num_channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"number of "
    "input/output "
    "channels\"},\"channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID "
    "of input/output "
    "channel\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative [m]\"},\"ext_subdivider\":{\"minimum\":"
    "0,\"type\":\"integer\",\"description\":\"reduces the frequency, default 1\"},\""
    "in_max_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"maximum "
    "delay to output pulse before fake event is generated [0.1 msec], zero "
    "indicates that no fake events are "
    "generated\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment"
    " in ticks\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive"
    " string\"},\"dmi_max_time\":{\"minimum\":0,\"type\":\"integer\",\"description\":\""
    "dmi, maximum time interval between trigger events [0.1 "
    "msec]\"},\"output_usage\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static high\"},\"in_min_duration\":{\"minim"
    "um\":0,\"type\":\"integer\",\"description\":\"input signals with smaller pulse"
    " durations are ignored [0.1 msec]\"},\"out_interval\":{\"minimum\":0,\"type\""
    ":\"integer\",\"description\":\"output pulse interval [0.1 "
    "msec]\"},\"ext_channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"ext_signal\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. use input signal, 1 .. use output signal of "
    "channel\"},\"input_usage\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\"},\"in_max_durati"
    "on\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"stops measurement of "
    "pulse duration of input signal [0.1 msec]\"},\"ttip_version\":{\"minimum\":"
    "0,\"type\":\"integer\",\"description\":\"following main.sub.ss.sss\"},\"out_pol"
    "arity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .. positive "
    "edge, 1 .. negative "
    "edge\"},\"in_polarity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .."
    " positive edge, 1 .. negative "
    "edge\"},\"out_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"output"
    " pulse initial delay after start [0.1 msec]\"},\"ext_bitmask\":{\"minimum\""
    ":0,\"type\":\"integer\",\"description\":\"defines which of the internal pulse"
    " generators are to be started\"},\"out_duration\":{\"minimum\":0,\"type\":\"in"
    "teger\",\"description\":\"output pulse duration [0.1 msec]\"},\"out_num_puls"
    "es\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"number of output "
    "pulses to be generated, 0 .. infinite\"},\"ext_delay\":{\"minimum\":0,\"type"
    "\":\"integer\",\"description\":\"external trigger, time delay [0.1 msec]\"}}}"
    ,
    /* example: */
    "{\"dmi_min_time\":0,\"num_channel\":9,\"channel\":0,\"dmi_dist_per_tick\":0.0,"
    "\"ext_subdivider\":1,\"in_max_delay\":9990,\"dmi_incr\":0,\"output_descr\":\"Po"
    "rt 1 - Trigger\",\"dmi_max_time\":0,\"output_usage\":1,\"in_min_duration\":0,"
    "\"out_interval\":10000,\"ext_channel\":32,\"input_descr\":\"Port 1 - Exposure"
    "\",\"ext_signal\":0,\"input_usage\":1,\"in_max_duration\":10000,\"ttip_version"
    "\":1,\"out_polarity\":0,\"in_polarity\":0,\"out_delay\":0,\"ext_bitmask\":0,\"ou"
    "t_duration\":300,\"out_num_pulses\":1,\"ext_delay\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "title\":\"Vertex Information\",\"description\":\"Details about vertex file\","
    "\"properties\":{\"vertex_file\":{\"type\":\"object\",\"required\":[\"file_extensi"
    "on\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading dot\"}}}}}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"definitions\":{\"v"
    "oxel_origin_point\":{\"maxItems\":3,\"type\":\"array\",\"items\":{\"type\":\"numbe"
    "r\"},\"description\":\"Origin point for all voxel indices in voxel CRS.\",\""
    "minItems\":3},\"voxel_type\":{\"enum\":[\"center\",\"centroid\",\"index\"],\"defau"
    "lt\":\"centroid\",\"description\":\"Whether a point in a voxel represents "
    "its center or its centroid. If type is <tt>index</tt> there is no "
    "point but only an integer voxel index.\"},\"edge_length\":{\"minimum\":0,\"t"
    "ype\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Length of voxel "
    "edge [m].\"},\"voxel_size_cubic\":{\"$ref\":\"#/definitions/edge_length\",\"ty"
    "pe\":\"number\"},\"voxel_size\":{\"maxItems\":3,\"type\":\"array\",\"items\":{\"$ref"
    "\":\"#/definitions/edge_length\"},\"description\":\"Size of voxels.\",\"minIte"
    "ms\":3},\"shape_thresholds\":{\"type\":\"object\",\"required\":[\"plane\",\"line\"]"
    ",\"description\":\"Thresholds used to compute the voxel's shape_id "
    "value.\",\"properties\":{\"plane\":{\"description\":\"If the smallest "
    "eigenvalue is smaller than the median eigenvalue * plane_threshold, "
    "the voxel is considered a plane.\",\"minimum\":0,\"type\":\"number\",\"exclusi"
    "veMinimum\":true,\"maximum\":1,\"exclusiveMaximum\":true},\"line\":{\"minimum\""
    ":1,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\"}}},\"voxel_origin_enum"
    "\":{\"enum\":[\"center\",\"corner\"],\"default\":\"corner\",\"description\":\"Define"
    "s whether the voxel's center or a corner is placed on CRS origin "
    "<tt>(0/0/0)</tt>.\"}},\"type\":\"object\",\"title\":\"Voxel "
    "Information\",\"description\":\"Details about the voxels contained in the "
    "file\",\"oneOf\":[{\"additionalProperties\":false,\"required\":[\"size\",\"voxel"
    "_origin\",\"voxel_type\"],\"properties\":{\"shape_thresholds\":{\"$ref\":\"#/def"
    "initions/shape_thresholds\"},\"voxel_origin\":{\"$ref\":\"#/definitions/voxe"
    "l_origin_enum\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size"
    "\":{\"description\":\"Size of voxels in file coordinate system.\",\"oneOf\":["
    "{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_"
    "cubic\"}]}}},{\"additionalProperties\":false,\"required\":[\"reference_point"
    "\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"],\"properties\":{\"refer"
    "ence_point\":{\"maxItems\":2,\"type\":\"array\",\"items\":{\"minimum\":-180,\"type"
    "\":\"number\",\"maximum\":180},\"description\":\"Point in WGS84 geodetic "
    "decimal degree (EPSG:4326) that was used to compute the projection "
    "distortion parameters. The coefficient order is latitude, longitude. "
    "Only voxels with corresponding geo_tag, voxel_size and reference_point"
    " can be reliably processed together. This entry is available for voxel"
    " files in projected CRS only.\",\"minItems\":2},\"size_llcs\":{\"$ref\":\"#/de"
    "finitions/voxel_size\",\"description\":\"Size of voxels in a locally "
    "levelled cartesian coordinate system (xyz). This is only used for "
    "voxels based on a map projection.\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\""
    "#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_origin_"
    "point\",\"description\":\"The base point of the voxel grid. Used together "
    "with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual "
    "point coordinates.\"}]},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\""
    "},\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size of "
    "voxels in file coordinate system.\"},\"shape_thresholds\":{\"$ref\":\"#/defi"
    "nitions/shape_thresholds\"}}}]}"
    ,
    /* example: */
    "{\"reference_point\":[48,16],\"size_llcs\":[0.5156575252891171,0.513083535"
    "6683303,0.5143705304787237],\"voxel_origin\":\"corner\",\"voxel_type\":\"cent"
    "roid\",\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"size\":[0.59716428347"
    "79395,0.5971642834779395,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"num_"
    "shots\",\"mta_zone\"],\"type\":\"object\",\"title\":\"Waveform Averaging "
    "Settings\",\"description\":\"Settings for waveform averaging\",\"properties\""
    ":{\"num_shots\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "consecutive shots to be used for averaging.\"},\"trim\":{\"minimum\":0,\"typ"
    "e\":\"number\",\"default\":0,\"maximum\":0.5,\"description\":\"Percentage for "
    "robust averaging.\"},\"mta_zone\":{\"minimum\":1,\"type\":\"integer\",\"descript"
    "ion\":\"Fixed MTA zone for averaging.\"}}}"
    ,
    /* example: */
    "{\"num_shots\":7,\"trim\":0.05,\"mta_zone\":1}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about waveform files\",\"type\":\"object\",\"title\":\"Waveform Informat"
    "ion\",\"required\":[\"sample_block_file\",\"sample_data_files\"],\"properties\""
    ":{\"sample_data_files\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"requir"
    "ed\":[\"channel\",\"channel_name\",\"sample_interval\",\"sample_bits\",\"laser_w"
    "avelength\",\"delta_st\",\"file_extension\"],\"properties\":{\"laser_wavelengt"
    "h\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\""
    ":\"Laser wavelength in meters (0 = unknown)\"},\"sample_bits\":{\"maximum\":"
    "32,\"minimum\":0,\"type\":\"integer\",\"exclusiveMinimum\":false,\"description\""
    ":\"Bitwidth of samples (e.g. 10 bit, 12 bit)\",\"exclusiveMaximum\":false}"
    ",\"sample_interval\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":fal"
    "se,\"description\":\"Sampling interval in seconds\"},\"channel\":{\"maximum\":"
    "255,\"minimum\":0,\"type\":\"integer\",\"exclusiveMinimum\":false,\"description"
    "\":\"Sample block channel number (255 = invalid)\",\"exclusiveMaximum\":fal"
    "se},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"},\"delta_st\":{\"type\":\"number\",\"description\":\"reserved\"},\""
    "file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample data "
    "file extension, without the leading dot\"}}}},\"sample_block_file\":{\"typ"
    "e\":\"object\",\"required\":[\"file_extension\"],\"properties\":{\"file_uuid\":{\""
    "type\":\"string\",\"description\":\"File's Universally Unique Identifier "
    "(RFC 4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample "
    "block file extension, without the leading dot\"}}},\"range_offset_wavefo"
    "rm_samples_m\":{\"type\":\"number\",\"description\":\"Calibrated device "
    "specific range offset for waveform samples in "
    "meters.\"},\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated "
    "device specific range offset for waveform analysis by system response "
    "fitting in meters.\"}}}"
    ,
    /* example: */
    "{\"sample_data_files\":[{\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d"
    "8e\",\"sample_bits\":12,\"sample_interval\":1.00503e-09,\"laser_wavelength\":"
    "0,\"channel_name\":\"high_power\",\"delta_st\":0,\"channel\":0,\"file_extension"
    "\":\"sp0\"},{\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"sample_b"
    "its\":12,\"sample_interval\":1.00503e-09,\"laser_wavelength\":0,\"channel_na"
    "me\":\"low_power\",\"delta_st\":0,\"channel\":1,\"file_extension\":\"sp1\"},{\"fil"
    "e_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"sample_bits\":12,\"sampl"
    "e_interval\":1.00503e-09,\"laser_wavelength\":0,\"channel_name\":\"wwf\",\"del"
    "ta_st\":0,\"channel\":5,\"file_extension\":\"sp5\"}],\"sample_block_file\":{\"fi"
    "le_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\""
    "},\"range_offset_waveform_samples_m \":7.283,\"range_offset_m\":3.1415}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"array\",\"t"
    "itle\":\"Waveform Settings\",\"items\":{\"type\":\"object\",\"required\":[\"sbl_na"
    "me\",\"enabled\",\"channel_idx_mask\"],\"properties\":{\"pass_ampl_less\":{\"typ"
    "e\":\"number\",\"description\":\"Threshold for amplitude less than "
    "[dB]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform"
    " output "
    "enabled\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold "
    "for range less than "
    "[m]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, "
    "...\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for range greater than [m]\"}}},\"description\":\"Scanner settings for "
    "waveform output\"}"
    ,
    /* example: */
    "[{\"pass_ampl_less\":5.0,\"smart_enabled\":true,\"pass_rng_less\":13.11,\"pas"
    "s_ampl_greater\":1.0,\"sbl_name\":\"wfm\",\"channel_idx_mask\":11,\"enabled\":t"
    "rue,\"pass_rng_greater\":9.27},{\"sbl_name\":\"wwf\",\"channel_idx_mask\":32,\""
    "enabled\":false}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"resu"
    "lt\",\"filter\",\"settings\"],\"type\":\"object\",\"title\":\"Window "
    "Analysis\",\"description\":\"Window analysis data estimated from scandata "
    "and resulting filter parameters\",\"properties\":{\"settings\":{\"type\":\"obj"
    "ect\",\"required\":[\"range\",\"amplitude\"],\"properties\":{\"range\":{\"type\":\"o"
    "bject\",\"required\":[\"sigma_factor\",\"additive_value\"],\"properties\":{\"add"
    "itive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}},\"amp"
    "litude\":{\"type\":\"object\",\"required\":[\"sigma_factor\",\"additive_value\"],"
    "\"properties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type"
    "\":\"number\"}}}}},\"filter\":{\"type\":\"object\",\"required\":[\"angle\",\"range_m"
    "in\",\"range_max\",\"amplitude_max\"],\"properties\":{\"amplitude_max\":{\"type\""
    ":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"range_min\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"},\"angle\":"
    "{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[deg]\"},\"rang"
    "e_max\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"}}"
    "},\"result\":{\"type\":\"object\",\"required\":[\"angle\",\"range_mean\",\"range_si"
    "gma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offset\"],\"propertie"
    "s\":{\"amplitude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descri"
    "ption\":\"[dB]\"},\"amplitude_sigma\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"description\":\"[dB]\"},\"range_sigma\":{\"type\":\"array\",\"items\":{\"typ"
    "e\":\"number\"},\"description\":\"[m]\"},\"range_mean\":{\"type\":\"array\",\"items\""
    ":{\"type\":\"number\"},\"description\":\"[m]\"},\"timestamp\":{\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\"},\"description\":\"[s]\"},\"amplitude_offset\":{\"type"
    "\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"angle\":{\"ty"
    "pe\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[deg]\"}}}}}"
    ,
    /* example: */
    "{\"settings\":{\"range\":{\"additive_value\":0.1,\"sigma_factor\":8},\"amplitud"
    "e\":{\"additive_value\":1.0,\"sigma_factor\":4}},\"filter\":{\"amplitude_max\":"
    "[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],\"range_min\":[-0"
    ".208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.223,-0.225,-0."
    "227],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"
    "\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.43"
    "1,0.432]},\"result\":{\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179"
    "926,5.097782,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],\"ampl"
    "itude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315"
    "141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"range_sigma\":["
    "0.01869652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01"
    "955329,0.02225589,0.02229977,0.01899122,0.02009433],\"range_mean\":[0.11"
    "05621,0.1079564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.101"
    "9044,0.1051523,0.1058445,0.1031261],\"timestamp\":[408.4441,411.4443],\"a"
    "mplitude_offset\":[1.9,1.9],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5"
    ",15.6,15.7,15.8,15.9]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ampl"
    "itude\",\"range\",\"slices\"],\"type\":\"object\",\"title\":\"Window Echo "
    "Correction\",\"description\":\"Correction parameters for window glass echo"
    "es\",\"properties\":{\"range\":{\"type\":\"object\",\"required\":[\"minimum\",\"maxi"
    "mum\",\"entries\"],\"description\":\"Range axis of correction table\",\"proper"
    "ties\":{\"minimum\":{\"minimum\":-2.0,\"type\":\"number\",\"maximum\":2.0,\"descri"
    "ption\":\"Minimum range in "
    "m\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "range entries\"},\"maximum\":{\"minimum\":-2.0,\"type\":\"number\",\"maximum\":2."
    "0,\"description\":\"Maximum range in m\"}}},\"amplitude\":{\"type\":\"object\",\""
    "required\":[\"minimum\",\"maximum\",\"entries\"],\"description\":\"Amplitude "
    "axis of correction table\",\"properties\":{\"minimum\":{\"minimum\":0.0,\"type"
    "\":\"number\",\"description\":\"Minimum amplitude in "
    "dB\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "amplitude entries\"},\"maximum\":{\"minimum\":0.0,\"type\":\"number\",\"descript"
    "ion\":\"Maximum amplitude in dB\"}}},\"slices\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"object\",\"required\":[\"amplitude\",\"table\"],\"description\":\"Window "
    "echo correction parameter slice\",\"properties\":{\"amplitude\":{\"type\":\"nu"
    "mber\",\"description\":\"Window echo amplitude of slice in dB\"},\"table\":{\""
    "type\":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"maxItems\":3,\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\",\"description\":\"Table cell (item 0: "
    "amplitude in dB, 1: range in m, 2: flags)\"},\"description\":\"Table "
    "column (= range axis)\",\"minItems\":3},\"description\":\"Table row (= "
    "amplitude axis)\",\"minItems\":1},\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"minItems\":1}}}}}}"
    ,
    /* example: */
    "{\"range\":{\"minimum\":-1.5060822940732335,\"entries\":128,\"maximum\":1.5060"
    "822940732335},\"amplitude\":{\"minimum\":2,\"entries\":128,\"maximum\":20},\"sl"
    "ices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]"
    "},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
